@@ -3,7 +3,7 @@
 
 from typing import Any
 import requests
-from jsonschema import validate
+from jsonschema import validate # dependency of another package
 
 
 def get_json_from_url(url: str, schema: Any = None) -> Any:
