@@ -36,10 +36,10 @@ def log_etl(
     schema: str,
     table: str,
     etl_date: datetime,
-    rows_inserted: int = -1,
-    rows_updated: int = -1,
-    rows_deleted: int = -1,
-    log_text: str = "",
+    rows_inserted: int | None = None,
+    rows_updated: int | None = None,
+    rows_deleted: int | None= None,
+    log_text: str| None = None,
 ) -> None:
     """
     inserts into logging table, does not commit
