@@ -13,6 +13,7 @@ def _get_knada_gke_secrets() -> dict[str, Any]:
     data = secret.payload.data.decode("UTF-8") # type: ignore
     return json.loads(data)
 
+
 def get_oracle_secrets_for(username: str) -> dict[str, str]:
     """reads and returns oracle secrets from knada gke"""
 
@@ -39,3 +40,9 @@ def get_dbt_oracle_secrets_for(username: str) -> dict[str, Any]:
         "ORACLE_PORT": dsn.split(":")[1].split("/")[0],
         "ORACLE_HOST": dsn.split(":")[0]
     }
+
+
+def get_kafka_secrets_for_topic(topic: str) -> dict[str, Any]:
+    """reads and returns kafka secrets from knada gke"""
+    raise NotImplementedError
+
