@@ -28,6 +28,8 @@ class FieldSchema:
         1
         >>> FieldSchema('x', int, default='?').extract_value({})
         '?'
+        >>> FieldSchema('x', int).rename
+        'x'
         """
         value = mapping.get(self.name)
         if value is None:
